@@ -2,7 +2,7 @@
 function(i) {
 if (missing(i)) messagena("i")
 x <- single(1)
-f.res <- .Fortran("mach",
+f.res <- .Fortran("machz",
 i=to.integer(i),
 x=to.single(x))
 list(x=f.res$x)
