@@ -1,7 +1,7 @@
 "precd" <-
 function() {
 prec <- double(1)
-f.res <- .Fortran("precd",
+f.res <- .Fortran("precdz",
 prec=as.double(prec))
 list(prec=f.res$prec)
 }
