@@ -3,7 +3,7 @@ function(x,sa,n=nrow(x),incx=1) {
 if (missing(sa)) messagena("sa")
 mdx <- length(x)
 if (missing(x)) x <- single(mdx)
-f.res <- .Fortran("scal",
+f.res <- .Fortran("scalz",
 x=to.single(x),
 sa=to.single(sa),
 n=to.integer(n),
