@@ -42,11 +42,11 @@ extern void F77_NAME(cia2b2z)(float*, int*, float*, int*, float*, float*);
 extern void F77_NAME(cibeatz)(float*, float*, int*, float*);
 extern void F77_NAME(ciclocz)(float*, float*, float*);
 extern void F77_NAME(cifactz)(float*, float*, int*, float*, int*, float*);
-extern void F77_NAME(cimedvz)(float*, int*, int*, int*, int*, int*, int*, float*, float*, float*);
+extern void F77_NAME(cimedvz)(float*, int*, int*, int*, int*, int*, int*, double*, float*, float*);
 extern void F77_NAME(cirockz)(float*, float*, int*, int*, float*);
-extern void F77_NAME(comvalz)(int*, float*, float*, float*, float*, float*, float*, float*, float*, int*, float*, float*, float*, float*, float*, float*, float*, float*, float*, float*, float*, float*, float*, int*);
+extern void F77_NAME(comvalz)(int*, float*, float*, float*, float*, float*, float*, float*, float*, int*, float*, float*, float*, float*, float*, float*, float*, float*, float*, float*, int*, float*, float*, int*);
 extern void F77_NAME(cquantz)(float*, int*, float*, int*, float*);
-extern void F77_NAME(dfcomnz)(int*, float*, float*, float*, float*, float*, float*, float*, float*, int*, float*, float*, float*, float*, float*, float*, float*, float*, float*, float*, float*, float*, float*, int*);
+extern void F77_NAME(dfcomnz)(int*, float*, float*, float*, float*, float*, float*, float*, float*, int*, float*, float*, float*, float*, float*, float*, float*, float*, float*, float*, int*, float*, float*, int*);
 extern void F77_NAME(dotpz)(float*, float*, int*, int*, int*, int*, int*, float*);
 extern void F77_NAME(dotpzd)(double*, double*, int*, int*, int*, int*, int*, double*);
 extern void F77_NAME(dpoissz)(float*, float*, float*, float*, float*, float*, int*, float*, float*);
@@ -72,7 +72,7 @@ extern void F77_NAME(ingamaz)(float*, float*, float*);
 
 extern void F77_NAME(int0)(int*, int*, int*, int*, int*, int*, float*, float*, float*, int*, float*, int*, float*, float*, float*);
 extern void F77_NAME(int10)(float*, double*, float*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, float*, float*, int*, float*, double*, double*, double*, double*, double*, double*);
-extern void F77_NAME(int16)(float*, double*, float*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, float*, float*, int*, float*, double*, double*, double*, double*, double*, double*, double*, double*, double*, double*);
+extern void F77_NAME(int16)(float*, double*, float*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, float*, float*, int*, float*, double*, double*, float*, double*, double*, double*, double*, double*, double*, double*);
 extern void F77_NAME(int21)(float*, float*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, float*, float*, float*, float*, int*, int*, int*, int*, int*, int*, int*, int*, float*, float*, float*, int*, float*, float*, int*);
 extern void F77_NAME(int21w)(float*, float*, float*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, float*, float*, float*, float*, int*, int*, int*, int*, int*, int*, int*, int*, float*, float*, float*, int*, float*, float*, int*);
 extern void F77_NAME(int24)(float*, int*, int*, int*, float*, float*, float*, float*, float*);
@@ -107,9 +107,9 @@ extern void F77_NAME(int67)(float*, double*);
 extern void F77_NAME(int68)(float*, double*);
 extern void F77_NAME(int69)(float*, double*);
 extern void F77_NAME(int7)(float*, double*, float*, int*, int*, int*, int*, int*, int*, int*, float*, int*, int*, int*, int*, float*, int*, float*, double*, double*, double*, double*);
-extern void F77_NAME(int70)(float*, float*, float*, double*);
+extern void F77_NAME(int70)(float*, int*, float*, double*);
 extern void F77_NAME(int9)(float*, double*, float*, int*, int*, int*, int*, int*, int*, int*, float*, int*, int*, int*, int*, float*, int*, float*, double*, double*, double*, double*);
-extern void F77_NAME(int92)(int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*, int*);
+extern void F77_NAME(int92)(float*, float*, float*, int*, int*, int*, float*, int*, float*, float*, int*, int*, int*, int*, int*, float*, float*, float*);
 
 extern void F77_NAME(kfascvz)(float*, float*, int*, int*, int*, int*, float*, float*, float*, int*);
 extern void F77_NAME(kiascvz)(float*, int*, int*, int*, int*, float*, float*, float*);
@@ -177,7 +177,7 @@ extern void F77_NAME(ribet0z)(float*, int*, int*, int*, float*, float*);
 extern void F77_NAME(ribethz)(float*, int*, float*, int*, float*);
 extern void F77_NAME(ricllsz)(float*, float*, int*, int*, int*, int*, int*, int*, int*, float*, float*, float*, float*, float*, float*, float*, float*, int*);
 extern void F77_NAME(rilarsz)(float*, float*, int*, int*, int*, int*, float*, int*, int*, int*, float*, float*, float*, float*, float*, float*, float*);
-extern void F77_NAME(rimtrdz)(double*, int*, int*, int*, int*, double*, float*, double*, double*, double*, int*);
+extern void F77_NAME(rimtrdz)(double*, int*, int*, int*, int*, float*, int*, double*, double*, double*, int*);
 extern void F77_NAME(rimtrfz)(float*, int*, int*, int*, int*, float*, int*, float*, float*, float*, int*);
 extern void F77_NAME(rmvcz)(float*, int*, int*, int*, int*, int*, float*, int*, float*);
 extern void F77_NAME(rubenz)(float*, float*, int*, int*, float*, float*, int*, float*, float*, float*, int*, float*, float*, float*, float*);
@@ -190,14 +190,14 @@ extern void F77_NAME(srt2z)(float*, float*, int*, int*, int*);
 extern void F77_NAME(stplrgz)(int*, float*, float*, float*, float*, float*, int*, float*, float*, float*, int*, float*, int*, int*, int*, float*, float*, float*, float*, float*, float*);
 extern void F77_NAME(swapz)(float*, float*, int*, int*, int*, int*, int*);
 extern void F77_NAME(swapzd)(double*, double*, int*, int*, int*, int*, int*);
-extern void F77_NAME(tauarez)(int*, int*, int*, float*, float*, float*, float*, float*, float*, int*, float*, int*);
+extern void F77_NAME(tauarez)(int*, int*, int*, float*, float*, float*, float*, float*, float*, int*, float*, float*);
 extern void F77_NAME(tfrn2tz)(float*, float*, int*, int*, int*, int*, float*, float*, float*);
 extern void F77_NAME(tisrtcz)(float*, int*, int*, int*, int*, int*, int*, int*);
 extern void F77_NAME(tquantz)(float*, int*, float*);
 extern void F77_NAME(ttasktz)(float*, float*, int*, int*, int*, int*, float*, float*, float*, float*);
 extern void F77_NAME(tteignz)(float*, int*, int*, int*, float*, int*, float*);
 extern void F77_NAME(wfshatz)(float*, int*, int*, int*, float*, float*, float*);
-extern void F77_NAME(wimedvz)(int*, int*, int*, int*, int*, int*, int*, int*, int*, int*);
+extern void F77_NAME(wimedvz)(float*, int*, int*, int*, int*, int*, int*, int*, double*, float*);
 extern void F77_NAME(xerfz)(int*, float*, float*);
 extern void F77_NAME(xerpz)(int*, float*, float*, float*);
 extern void F77_NAME(xsyz)(float*, float*, float*, int*, int*, float*);
@@ -214,11 +214,11 @@ extern void F77_NAME(regtau)(double*, double*, int*, int*, float*, float*, float
 extern void F77_NAME(regtauw)(double*, double*, double*, int*, int*, float*, float*, float*, float*, float*, int*, double*, double*, double*, double*, double*, double*, double*, float*, float*);
 extern void F77_NAME(rhoa)(int*, float*, float*);
 extern void F77_NAME(rpardf)(float*, int*, int*, int*, int*, float*, float*, int*, int*, int*);
-extern void F77_NAME(ucva)(int*, float*, float*);
-extern void F77_NAME(upcva)(int*, float*, float*);
-extern void F77_NAME(wcva)(int*, float*, float*);
-extern void F77_NAME(wpcva)(int*, float*, float*);
-extern void F77_NAME(wwwa)(int*, float*, float*);
+extern void F77_NAME(ucva)(int*, float*, double*);
+extern void F77_NAME(upcva)(int*, float*, double*);
+extern void F77_NAME(wcva)(int*, float*, double*);
+extern void F77_NAME(wpcva)(int*, float*, double*);
+extern void F77_NAME(wwwa)(int*, float*, double*);
 extern void F77_NAME(zdfvals)(int*, float*);
 
 static const R_FortranMethodDef FortranEntries[] = {
